var XYZR_8h =
[
    [ "EdgePairGeometry", "classIMP_1_1core_1_1EdgePairGeometry.html", "classIMP_1_1core_1_1EdgePairGeometry" ],
    [ "EdgePairsGeometry", "classIMP_1_1core_1_1EdgePairsGeometry.html", "classIMP_1_1core_1_1EdgePairsGeometry" ],
    [ "XYZDerivativeGeometry", "classIMP_1_1core_1_1XYZDerivativeGeometry.html", "classIMP_1_1core_1_1XYZDerivativeGeometry" ],
    [ "XYZDerivativesGeometry", "classIMP_1_1core_1_1XYZDerivativesGeometry.html", "classIMP_1_1core_1_1XYZDerivativesGeometry" ],
    [ "XYZR", "classIMP_1_1core_1_1XYZR.html", "classIMP_1_1core_1_1XYZR" ],
    [ "XYZRGeometry", "classIMP_1_1core_1_1XYZRGeometry.html", "classIMP_1_1core_1_1XYZRGeometry" ],
    [ "XYZRsGeometry", "classIMP_1_1core_1_1XYZRsGeometry.html", "classIMP_1_1core_1_1XYZRsGeometry" ],
    [ "XYZRs", "XYZR_8h.html#a55244f032d68e041e9b58b424e2afca5", null ],
    [ "create_xyzr_particles", "XYZR_8h.html#ab187aead985c4fb93d7c4c8741fb00c8", null ],
    [ "get_distance", "XYZR_8h.html#ad65d79ddb3c6e1db815d57f73c8f18ea", null ],
    [ "get_enclosing_sphere", "XYZR_8h.html#ac28cbff46cedec4186ab8e63a3c3b41b", null ],
    [ "set_enclosing_radius", "XYZR_8h.html#a25735ab61a19f9813d051462afd24b2f", null ],
    [ "set_enclosing_sphere", "XYZR_8h.html#a9f00e88e92a88b5ef349978fe737df7d", null ]
];